#!/bin/bash

################################################################
# WebLogic-OutSystems: Common utils
################################################################

# WebLogic - OutSystems Log
LOGFILE="/dev/null"

source $OUTSYSTEMS_HOME/common.sh

function getProperty(){

    RESULT=$(grep -i $@ $OUTSYSTEMS_HOME/server.hsconf | cut -d ">" -f 2 | cut -d "<" -f 1 2>/dev/null)
    echo "getProperty $@ = "$RESULT >> $LOGFILE
    echo $RESULT
}

function performValidations(){
    if [ "$WL_DOMAIN" == "" ]
    then
        log_warning_msg "Environment Variable missing: WL_DOMAIN"
        log_end_msg 1
        exit 1
    fi
}

function isAdminServer(){
	chkconfig --list "weblogic-outsystems-adminserver" 2>/dev/null | grep :on 1>/dev/null
}

function isNodeManager(){
	chkconfig --list "weblogic-outsystems-nodemanager" 2>/dev/null | grep :on 1>/dev/null
}

function getNodeManagerPID(){
    NODEMANAGER_PID=$(pgrep -u $(getWeblogicOutSystemsUser) -f "weblogic.NodeManager")
    echo "NODEMANAGER_PID=$NODEMANAGER_PID" >> $LOGFILE
    echo $NODEMANAGER_PID
}

function getWeblogicOutSystemsUser(){

    #WL_DOMAIN owner will be the user used to start | stop the WebLogic services
    WL_OSUSER=$(stat -c %U $WL_DOMAIN)

    if [ "$WL_OSUSER" == "" ]
    then
        log_daemon_msg "WebLogic OutSystems user not found"
        log_end_msg 1
        exit 1
    fi

    echo $WL_OSUSER
}

function getWeblogicOutSystemsGroup(){

    WL_OSUSER=$(stat -c %G $WL_DOMAIN)

    if [ "$WL_OSUSER" == "" ]
    then
        log_daemon_msg "WebLogic OutSystems group not found"
        log_end_msg 1
        exit 1
    fi

    echo $WL_OSUSER
}

function getWeblogicAdminConsoleUser(){
    getProperty OutSystems.Weblogic.ConsoleUsername
}

function getOutSystemsServerName(){
    getProperty OutSystems.Weblogic.ServerTarget
}

function runJMX(){
        $JAVA_HOME/bin/java -classpath /opt/outsystems/platform/lib/*:/opt/outsystems/platform/outsystems.hubedition.runtimeplatformutil.jar:/opt/outsystems/platform/outsystems.hubedition.runtimecommon.jar:/opt/outsystems/platform/outsystems.hubedition.common.jar:/opt/outsystems/platform/outsystems.hubedition.runtimeplatform.jar:/opt/outsystems/platform/outsystems.hubedition.servercommon.jar:/opt/outsystems/platform/outsystems.runtimeservices.jar:/opt/outsystems/platform/lib/active.connectors/*:/opt/outsystems/platform/deployservice.jar outsystems.connector.weblogic.WebLogicServices $1
     RETVAL=$?
}

function activateLog(){
    LOGFILE="$OUTSYSTEMS_HOME/logs/weblogic-outsystems.log" ;
    if [ ! -f $LOGFILE ]
    then
        touch $LOGFILE
    fi
    chown $(getWeblogicOutSystemsUser)":"$(getWeblogicOutSystemsGroup) $LOGFILE
}

#activateLog


